@@ -71,10 +71,13 @@ static char synopsisString[] =
         "'specialFlags1' Optional flags, numbers to be added together: 1 = Use YUV video decoding instead of RGBA, if "
         "supported by movie codec and GPU - May be more efficient. 2 = Don't decode and use sound - May be more efficient. "
         "On Linux you may need to specify a setting of 2 if you try to use movie playback at the same time as "
-        "PsychPortAudio sound output, otherwise movie playback may hang. A flag of 4 will draw motion vectors on top "
-        "of decoded video frames, for debugging or entertainment. A flag of 8 will ask the video decoder to skip all "
-        "B-Frames during decoding to reduce processor load on very slow machines. Not all codecs may support flags 4 or "
-        "8, in which case these flags are silently ignored. A flag of 16 asks Screen to convert all video textures "
+        "PsychPortAudio sound output, otherwise movie playback may hang. A flag of 4 will try to disable gpu hardware "
+        "accelerated video decoding for playback of this and all future movies for the running Octave/Matlab session on "
+        "GStreamer 1.16 and earlier. On GStreamer 1.18 and later, the disable will only affect the to be opened movie, "
+        "giving more dynamic control over use of hardware video acceleration. "
+        "A flag of 8 will ask the video decoder to skip all B-Frames during decoding to reduce processor load on very "
+        "slow machines. Not all codecs may support flag 8, in which case these flags are silently ignored. "
+        "A flag of 16 asks Screen to convert all video textures "
         "immediately into a format which makes them useable as offscreen windows, and for the Screen('TransformTexture') "
         "function as well as for drawing them with your own custom GLSL shaders. Normally this conversion would be "
         "deferred until needed, ie. it would get skipped if you would just draw the texture regularly. If you know "
