@@ -366,7 +366,7 @@ try
                 % Draw some info about movie, but only if needed. In HDR mode we only draw text
                 % once in the first frame, then do not clear the framebuffer later on. Why? Because
                 % text drawing can be a rather expensive operation, impairing high fps playback.
-                if colorprobe || ~hdr || (i == 0)
+                if colorprobe || (~hdr && fps < 30) || (i == 0)
                     DrawFormattedText(win, ['Movie: ' moviename ], 'center', 20, 0);
                     if coolstuff
                         DrawFormattedText(win, ['Original URL: ' url '\n\n' credits], 'center', 60, 0);
@@ -403,8 +403,9 @@ try
                     % some overhead:
                     Screen('Flip', win, [], 1);
                 else
-                    % Regular without real use of imaging pipeline:
-                    Screen('Flip', win);
+                    % Regular without real use of imaging pipeline. Skip waiting
+                    % for flip completion, to squeeze out a bit more fps:
+                    Screen('Flip', win, [], [], 1);
                 end
 
                 % Release texture:
